@@ -20,7 +20,8 @@
 #' - `conditional`, the names of the predictor variables from the *conditional*
 #'    model (as opposed to the zero-inflated part of a model)
 #' - `random`, the names of the random effects (grouping factors)
-#' - `zero_inflated`, the names of the predictor variables from the *zero-inflated* part of the model
+#' - `zero_inflated`, the names of the predictor variables from the
+#'   *zero-inflated* part of the model
 #' - `zero_inflated_random`, the names of the random effects (grouping factors)
 #' - `dispersion`, the name of the dispersion terms
 #' - `instruments`, the names of instrumental variables
@@ -54,11 +55,13 @@ find_terms <- function(x, ...) {
 
 #' @rdname find_terms
 #' @export
-find_terms.default <- function(x,
-                               flatten = FALSE,
-                               as_term_labels = FALSE,
-                               verbose = TRUE,
-                               ...) {
+find_terms.default <- function(
+  x,
+  flatten = FALSE,
+  as_term_labels = FALSE,
+  verbose = TRUE,
+  ...
+) {
   f <- find_formula(x, verbose = verbose)
 
   if (is.null(f)) {
@@ -100,6 +103,28 @@ find_terms.default <- function(x,
 }
 
 
+#' @export
+find_terms.insight_formula <- function(x, flatten = FALSE, verbose = TRUE, ...) {
+  if (is.null(x)) {
+    return(NULL)
+  }
+
+  resp <- find_response(x, verbose = FALSE)
+
+  if (is_multivariate(x)) {
+    l <- lapply(x, .get_variables_list, resp = resp, model = NULL)
+  } else {
+    l <- .get_variables_list(x, resp, model = NULL)
+  }
+
+  if (flatten) {
+    unique(unlist(l, use.names = FALSE))
+  } else {
+    l
+  }
+}
+
+
 #' @export
 find_terms.aovlist <- function(x, flatten = FALSE, verbose = TRUE, ...) {
   resp <- find_response(x, verbose = FALSE)
@@ -156,7 +181,6 @@ find_terms.bfsl <- function(x, flatten = FALSE, verbose = TRUE, ...) {
 
 # unsupported ------------------
 
-
 #' @export
 find_terms.mipo <- function(x, flatten = FALSE, ...) {
   l <- list(conditional = unique(as.vector(summary(x)$term)))
@@ -170,7 +194,6 @@ find_terms.mipo <- function(x, flatten = FALSE, ...) {
 
 # helper -----------------------
 
-
 .get_variables_list <- function(f, resp = NULL, model = NULL) {
   # exception for formula w/o response
   if (is.null(resp) || !is_empty_object(resp)) {
@@ -200,10 +223,15 @@ find_terms.mipo <- function(x, flatten = FALSE, ...) {
   # unless they are preceded by a ^ and followed by a closing parenthesis ).
   f <- lapply(f, function(.x) {
     pattern <- "(?<!\\^)[*+:|\\-\\/](?![^(]*\\))" # was: "[\\*\\+:\\-\\|/](?![^(]*\\))"
-    f_parts <- gsub("~", "", trim_ws(unlist(
-      strsplit(split = pattern, x = .x, perl = TRUE),
-      use.names = FALSE
-    )), fixed = TRUE)
+    f_parts <- gsub(
+      "~",
+      "",
+      trim_ws(unlist(
+        strsplit(split = pattern, x = .x, perl = TRUE),
+        use.names = FALSE
+      )),
+      fixed = TRUE
+    )
     # if user has used namespace in formula-functions, these are returned
     # as empty elements. remove those here
     if (!all(nzchar(f_parts, keepNA = TRUE))) {
@@ -214,7 +242,12 @@ find_terms.mipo <- function(x, flatten = FALSE, ...) {
 
   # exceptions where we want to preserve the response value come here
   # - lm(1 / Sepal.Length ~ Species, data = iris)
-  if (!is.null(original_response) && !is_empty_object(original_response) && startsWith(original_response, "1/")) { # nolint
+  if (
+    !is.null(original_response) &&
+      !is_empty_object(original_response) &&
+      startsWith(original_response, "1/")
+  ) {
+    # nolint
     f$response <- original_response
   }
 
@@ -227,14 +260,12 @@ find_terms.mipo <- function(x, flatten = FALSE, ...) {
 
   # remove "1" and "0" from variables in random effects
 
-  if (object_has_names(f, "random")) {
-    pos <- which(f$random %in% c("1", "0"))
-    if (length(pos)) f$random <- f$random[-pos]
-  }
-
-  if (object_has_names(f, "zero_inflated_random")) {
-    pos <- which(f$zero_inflated_random %in% c("1", "0"))
-    if (length(pos)) f$zero_inflated_random <- f$zero_inflated_random[-pos]
+  re_comp <- endsWith(names(f), "random")
+  if (any(re_comp)) {
+    for (i in names(f)[re_comp]) {
+      pos <- which(f[[i]] %in% c("1", "0"))
+      if (length(pos)) f[[i]] <- f[[i]][-pos]
+    }
   }
 
   # restore -1
@@ -242,7 +273,10 @@ find_terms.mipo <- function(x, flatten = FALSE, ...) {
   if (any(need_split)) {
     f$conditional <- c(
       f$conditional[!need_split],
-      trim_ws(unlist(strsplit(f$conditional[need_split], " ", fixed = TRUE), use.names = FALSE))
+      trim_ws(unlist(
+        strsplit(f$conditional[need_split], " ", fixed = TRUE),
+        use.names = FALSE
+      ))
     )
   }
 
@@ -255,10 +289,14 @@ find_terms.mipo <- function(x, flatten = FALSE, ...) {
 
 
 .get_variables_list_aovlist <- function(f, resp = NULL) {
-  i <- vapply(f[[3]], function(x) {
-    x <- as.character(x)
-    x[1] == "Error" && length(x) > 1
-  }, TRUE)
+  i <- vapply(
+    f[[3]],
+    function(x) {
+      x <- as.character(x)
+      x[1] == "Error" && length(x) > 1
+    },
+    TRUE
+  )
   error <- utils::capture.output(print(f[[3]][i][[1]]))
   f[[3]][i] <- NULL
   f[[3]] <- f[[3]][[2]]
@@ -271,6 +309,8 @@ find_terms.mipo <- function(x, flatten = FALSE, ...) {
 }
 
 .formula_to_string <- function(f) {
-  if (!is.character(f)) f <- safe_deparse(f)
+  if (!is.character(f)) {
+    f <- safe_deparse(f)
+  }
   f
 }
