@@ -20,10 +20,13 @@
 #'
 #' @details Currently, only sigma and the dispersion parameter are returned, and
 #' only for a limited set of models.
-#' \subsection{Sigma Parameter}{
-#' See [get_sigma()].
-#' }
-#' \subsection{Dispersion Parameter}{
+#'
+#' @section Sigma Parameter:
+#'
+#' See [`get_sigma()`].
+#'
+#' @section  Dispersion Parameter:
+#'
 #' There are many different definitions of "dispersion", depending on the context.
 #' `get_auxiliary()` returns the dispersion parameters that usually can
 #' be considered as variance-to-mean ratio for generalized (linear) mixed
@@ -36,12 +39,12 @@
 #' and is the ratio of the sum of the squared Pearson-residuals and the residual
 #' degrees of freedom. For models of class `glmmTMB`, dispersion is
 #' \ifelse{html}{\out{&sigma;<sup>2</sup>}}{\eqn{\sigma^2}}.
-#' }
-#' \subsection{**brms** models}{
+#'
+#' @section  brms-models:
+#'
 #' For models of class `brmsfit`, there are different options for the
 #' `type` argument. See a list of supported auxiliary parameters here:
-#' [find_parameters.BGGM()].
-#' }
+#' [`find_parameters.BGGM()`].
 #'
 #' @examples
 #' # from ?glm
@@ -53,13 +56,18 @@
 #' model <- glm(lot1 ~ log(u), data = clotting, family = Gamma())
 #' get_auxiliary(model, type = "dispersion") # same as summary(model)$dispersion
 #' @export
-get_auxiliary <- function(x,
-                          type = "sigma",
-                          summary = TRUE,
-                          centrality = "mean",
-                          verbose = TRUE,
-                          ...) {
-  type <- match.arg(type, choices = .aux_elements())
+get_auxiliary <- function(
+  x,
+  type = "sigma",
+  summary = TRUE,
+  centrality = "mean",
+  verbose = TRUE,
+  ...
+) {
+  type <- validate_argument(
+    type,
+    unique(c(.aux_elements(), .brms_aux_elements(), "all"))
+  )
 
   if (inherits(x, "brmsfit")) {
     return(.get_generic_aux(x, type, summary = summary, centrality = centrality))
@@ -73,22 +81,29 @@ get_auxiliary <- function(x,
 }
 
 
-
-
-
 # dispersion parameter -----------------------
 
-#' @keywords internal
+#' @rdname get_auxiliary
+#' @export
 get_dispersion <- function(x, ...) {
   UseMethod("get_dispersion")
 }
 
-#' @keywords internal
+#' @rdname get_auxiliary
+#' @export
+get_dispersion.default <- function(x, ...) {
+  format_error(sprintf(
+    "`get_dispersion()` does not yet support models of class \"%s\".",
+    class(x)[1]
+  )) # nolint
+}
+
+#' @export
 get_dispersion.model_fit <- function(x, ...) {
   get_dispersion(x$fit, ...)
 }
 
-#' @keywords internal
+#' @export
 get_dispersion.glm <- function(x, verbose = TRUE, ...) {
   info <- model_info(x, verbose = verbose)
   disp <- NULL
@@ -103,7 +118,7 @@ get_dispersion.glm <- function(x, verbose = TRUE, ...) {
   disp
 }
 
-#' @keywords internal
+#' @export
 get_dispersion.glmerMod <- function(x, verbose = TRUE, ...) {
   info <- model_info(x, verbose = verbose)
   disp <- NULL
@@ -122,7 +137,7 @@ get_dispersion.glmerMod <- function(x, verbose = TRUE, ...) {
   disp
 }
 
-#' @keywords internal
+#' @export
 get_dispersion.glmmTMB <- function(x, verbose = TRUE, ...) {
   info <- model_info(x, verbose = verbose)
   disp <- NULL
@@ -135,25 +150,35 @@ get_dispersion.glmmTMB <- function(x, verbose = TRUE, ...) {
   disp
 }
 
-#' @keywords internal
+#' @export
 get_dispersion.brmsfit <- get_dispersion.glmmTMB
 
 
-
 # special ------------------
 
 #' @keywords internal
-.get_generic_aux <- function(x,
-                             param,
-                             summary = TRUE,
-                             centrality = "mean",
-                             ...) {
+.get_generic_aux <- function(x, param, summary = TRUE, centrality = "mean", ...) {
   aux <- NULL
   if (inherits(x, "brmsfit")) {
-    aux <- as.data.frame(x)[[param]]
+    if (all(param == "all")) {
+      param <- find_auxiliary(x)
+    }
+    # get posterior draws
+    aux <- as.data.frame(x)
+    # find parameter names of distributional parameters
+    param_names <- unlist(find_parameters(x)[param], use.names = FALSE)
+    # intersect only available columns
+    param <- intersect(param_names, colnames(aux))
+    # check if any distributional parameter available
+    if (is.null(param) || !length(param)) {
+      format_warning(paste0("No auxiliary parameters found."))
+      return(NULL)
+    }
+    aux <- aux[param]
     if (summary) {
       aux <- .summary_of_posteriors(aux, centrality = centrality)
     }
   }
+
   aux
 }
