@@ -15,6 +15,7 @@
 #'
 #' @param x A model.
 #' @param ci Scalar, the CI level. The default (`NULL`) returns no CI.
+#' @param ... For internal use.
 #' @inheritParams find_parameters
 #'
 #' @return The residual standard deviation (sigma), or `NULL` if this
@@ -49,8 +50,8 @@
 #' m <- lm(mpg ~ wt + cyl + vs, data = mtcars)
 #' get_sigma(m)
 #' @export
-get_sigma <- function(x, ci = NULL, verbose = TRUE) {
-  s <- .get_sigma(x, verbose = verbose)
+get_sigma <- function(x, ci = NULL, verbose = TRUE, ...) {
+  s <- .get_sigma(x, verbose = verbose, ...)
 
   # Confidence interval for sigma
   ci <- .safe(.get_sigma_ci(x, ci = ci))
@@ -65,7 +66,6 @@ get_sigma <- function(x, ci = NULL, verbose = TRUE) {
 
 # Retrieve sigma ----------------------------------------------------------
 
-
 .get_sigma <- function(x, ...) {
   UseMethod(".get_sigma")
 }
@@ -73,7 +73,6 @@ get_sigma <- function(x, ci = NULL, verbose = TRUE) {
 
 # special handling ---------------
 
-
 .get_sigma.glmerMod <- function(x, ...) {
   check_if_installed("lme4")
   if (startsWith(stats::family(x)$family, "Negative Binomial(")) {
@@ -123,12 +122,26 @@ get_sigma <- function(x, ci = NULL, verbose = TRUE) {
 }
 
 
+.get_sigma.afex_aov <- function(x, verbose = TRUE, ...) {
+  s <- .safe({
+    model_deviance <- get_deviance(x, verbose = verbose)
+    residual_df <- suppressWarnings(get_df(x, type = "residual", model = "univariate"))
+    sqrt(abs(model_deviance) / residual_df)
+  })
+  if (is_empty_object(s)) {
+    return(NULL)
+  }
+  class(s) <- c("insight_aux", class(s))
+  s
+}
+
+
 .get_sigma.model_fit <- function(x, verbose = TRUE, ...) {
   .get_sigma(x$fit, verbose = verbose)
 }
 
 
-.get_sigma.lrm <- function(x, verbose = TRUE, ...) {
+.get_sigma.lrm <- function(x, ...) {
   s <- stats::sigma(x)
   s <- s[length(s)]
   class(s) <- c("insight_aux", class(s))
@@ -136,14 +149,14 @@ get_sigma <- function(x, ci = NULL, verbose = TRUE) {
 }
 
 
-.get_sigma.VGAM <- function(x, verbose = TRUE, ...) {
+.get_sigma.VGAM <- function(x, ...) {
   s <- .safe(exp(stats::coef(x)[["(Intercept):2"]]))
   class(s) <- c("insight_aux", class(s))
   s
 }
 
 
-.get_sigma.merModList <- function(x, verbose = TRUE, ...) {
+.get_sigma.merModList <- function(x, ...) {
   s <- suppressWarnings(summary(x))
   s <- s$residError
   class(s) <- c("insight_aux", class(s))
@@ -151,14 +164,14 @@ get_sigma <- function(x, ci = NULL, verbose = TRUE) {
 }
 
 
-.get_sigma.summary.lm <- function(x, verbose = TRUE, ...) {
+.get_sigma.summary.lm <- function(x, ...) {
   s <- x$sigma
   class(s) <- c("insight_aux", class(s))
   s
 }
 
 
-.get_sigma.selection <- function(x, verbose = TRUE, ...) {
+.get_sigma.selection <- function(x, ...) {
   s <- unname(stats::coef(x)["sigma"])
   class(s) <- c("insight_aux", class(s))
   s
@@ -166,13 +179,10 @@ get_sigma <- function(x, ci = NULL, verbose = TRUE) {
 
 
 .get_sigma.cgam <- function(x, verbose = TRUE, ...) {
-  s <- tryCatch(
-    {
-      sqrt(get_deviance(x, verbose = verbose) / get_df(x, type = "residual", verbose = verbose))
-    },
-    error = function(e) {
-      NULL
-    }
+  s <- .safe(
+    sqrt(
+      get_deviance(x, verbose = verbose) / get_df(x, type = "residual", verbose = verbose)
+    )
   )
 
   if (is_empty_object(s)) {
@@ -184,7 +194,7 @@ get_sigma <- function(x, ci = NULL, verbose = TRUE) {
 }
 
 
-.get_sigma.cpglmm <- function(x, verbose = TRUE, ...) {
+.get_sigma.cpglmm <- function(x, ...) {
   s <- .safe(stats::deviance(x)[["sigmaML"]])
   if (!is.null(s)) {
     class(s) <- c("insight_aux", class(s))
@@ -198,27 +208,32 @@ get_sigma <- function(x, ci = NULL, verbose = TRUE) {
 }
 
 
+.get_sigma.geeglm <- function(x, ...) {
+  out <- .safe(stats::sigma(x))
+  if (is.data.frame(out)) {
+    out <- out$Estimate
+  }
+  out
+}
+
+
 .get_sigma.mjoint <- function(x, ...) {
   .safe(x$coef$sigma2[[1]])
 }
 
 
 .get_sigma.glmmPQL <- function(x, ...) {
-  switch(x$family$family,
-    gaussian = ,
-    Gamma = x$sigma,
-    x$sigma^2
-  )
+  switch(x$family$family, gaussian = , Gamma = x$sigma, x$sigma^2)
 }
 
 
-.get_sigma.brmsfit <- function(x, verbose = TRUE, ...) {
+.get_sigma.brmsfit <- function(x, ...) {
   s <- tryCatch(
     {
       dat <- as.data.frame(x)
       sigma_column <- grep("sigma", colnames(dat), fixed = TRUE)
       if (length(sigma_column) == 1) {
-        mean(dat[[sigma_column]][1])
+        mean(dat[[sigma_column]])
       } else if (length(sigma_column)) {
         # if more than one sigma column,
         # there isn't a traditional sigma for the model
@@ -231,8 +246,6 @@ get_sigma <- function(x, ci = NULL, verbose = TRUE) {
       NULL
     }
   )
-
-
   # compute sigma manually ---------------
   if (is_empty_object(s)) {
     # default sigma ---------------
@@ -240,9 +253,14 @@ get_sigma <- function(x, ci = NULL, verbose = TRUE) {
   }
 
   if (is_empty_object(s)) {
-    info <- model_info(x, verbose = FALSE)
+    info <- model_info(x, response = 1, verbose = FALSE)
     if (!is.null(info) && info$is_mixed) {
-      s <- .safe(sqrt(get_variance_residual(x, verbose = FALSE)))
+      dots <- list(...)
+      # in "get_variance()", we call "get_sigma()" - make sure we avoid
+      # recursion and infinite loops
+      if (!isTRUE(dots$no_recursion)) {
+        s <- .safe(sqrt(get_variance_residual(x, verbose = FALSE)))
+      }
     }
   }
 
@@ -254,7 +272,6 @@ get_sigma <- function(x, ci = NULL, verbose = TRUE) {
 }
 
 
-
 # default handling ---------------
 
 .get_sigma.default <- function(x, verbose = TRUE, ...) {
@@ -265,7 +282,6 @@ get_sigma <- function(x, ci = NULL, verbose = TRUE) {
   # default sigma ---------------
   s <- .safe(stats::sigma(x))
 
-
   # compute sigma manually ---------------
   if (is_empty_object(s)) {
     info <- model_info(x, verbose = FALSE)
@@ -291,7 +307,6 @@ get_sigma <- function(x, ci = NULL, verbose = TRUE) {
 }
 
 
-
 # Methods -----------------------------------------------------------------
 
 .get_sigma_ci <- function(x, ci = 0.95, ...) {
@@ -310,11 +325,13 @@ get_sigma <- function(x, ci = NULL, verbose = TRUE) {
 }
 
 
-
 #' @export
-as.numeric.insight_aux <- function(x, ...) {
-  if (is.null(x) || is.na(x) || is.infinite(x)) {
+as.double.insight_aux <- function(x, ...) {
+  if (is.null(x) || all(is.na(x)) || all(is.infinite(x)) || !is.numeric(x)) {
     return(NULL)
   }
   mean(x, na.rm = TRUE)
 }
+
+#' @export
+as.numeric.insight_aux <- as.double.insight_aux
