@@ -31,7 +31,6 @@ link_inverse <- function(x, ...) {
 
 # Default method ---------------------------------------
 
-
 #' @export
 link_inverse.default <- function(x, ...) {
   if (inherits(x, "list") && object_has_names(x, "gam")) {
@@ -67,7 +66,8 @@ link_inverse.default <- function(x, ...) {
   }
   # if all fails, force default link
   if (is.null(out) && !is.null(default_link)) {
-    out <- switch(default_link,
+    out <- switch(
+      default_link,
       identity = .safe(stats::gaussian(link = "identity")$linkinv),
       .safe(stats::make.link(link = default_link)$linkinv)
     )
@@ -89,6 +89,12 @@ link_inverse.speedglm <- link_inverse.glm
 #' @export
 link_inverse.bigglm <- link_inverse.glm
 
+#' @export
+link_inverse.externX <- link_inverse.glm
+
+#' @export
+link_inverse.externVar <- link_inverse.glm
+
 #' @export
 link_inverse.nestedLogit <- function(x, ...) {
   stats::make.link(link = "logit")$linkinv
@@ -97,7 +103,6 @@ link_inverse.nestedLogit <- function(x, ...) {
 
 # Tobit Family ---------------------------------
 
-
 #' @export
 link_inverse.tobit <- function(x, ...) {
   .make_tobit_family(x)$linkinv
@@ -239,8 +244,12 @@ link_inverse.svy2lme <- link_inverse.lm
 #' @export
 link_inverse.betareg <- function(x, what = c("mean", "precision"), ...) {
   what <- match.arg(what)
-  switch(what,
-    mean = x$link$mean$linkinv,
+
+  element_name <- .betareg_mean_element(x)
+
+  switch(
+    what,
+    mean = x$link[[element_name]]$linkinv,
     precision = x$link$precision$linkinv
   )
 }
@@ -253,7 +262,8 @@ link_inverse.DirichletRegModel <- function(x, what = c("mean", "precision"), ...
   if (x$parametrization == "common") {
     stats::make.link("logit")$linkinv
   } else {
-    switch(what,
+    switch(
+      what,
       mean = stats::make.link("logit")$linkinv,
       precision = stats::make.link("log")$linkinv
     )
@@ -389,7 +399,6 @@ link_inverse.mixor <- link_inverse.clm
 
 # mfx models ------------------------------------------------------
 
-
 #' @rdname link_inverse
 #' @export
 link_inverse.betamfx <- function(x, what = c("mean", "precision"), ...) {
@@ -434,7 +443,8 @@ link_inverse.Rchoice <- function(x, ...) {
 
 #' @export
 link_inverse.oohbchoice <- function(x, ...) {
-  link <- switch(x$distribution,
+  link <- switch(
+    x$distribution,
     normal = "identity",
     weibull = ,
     "log-normal" = "log",
@@ -454,7 +464,8 @@ link_inverse.merModList <- function(x, ...) {
 
 #' @export
 link_inverse.robmixglm <- function(x, ...) {
-  switch(tolower(x$family),
+  switch(
+    tolower(x$family),
     gaussian = stats::make.link(link = "identity")$linkinv,
     binomial = stats::make.link(link = "logit")$linkinv,
     gamma = stats::make.link(link = "inverse")$linkinv,
@@ -502,7 +513,8 @@ link_inverse.fixest <- function(x, ...) {
   } else if (inherits(x$family, "family")) {
     x$family$linkinv
   } else {
-    link <- switch(x$family,
+    link <- switch(
+      x$family,
       poisson = ,
       negbin = "log",
       logit = "logit",
@@ -540,7 +552,9 @@ link_inverse.glmmadmb <- function(x, ...) {
 #' @export
 link_inverse.polr <- function(x, ...) {
   link <- x$method
-  if (link == "logistic") link <- "logit"
+  if (link == "logistic") {
+    link <- "logit"
+  }
   stats::make.link(link)$linkinv
 }
 
@@ -548,7 +562,9 @@ link_inverse.polr <- function(x, ...) {
 #' @export
 link_inverse.svyolr <- function(x, ...) {
   link <- x$method
-  if (link == "logistic") link <- "logit"
+  if (link == "logistic") {
+    link <- "logit"
+  }
   stats::make.link(link)$linkinv
 }
 
@@ -564,6 +580,13 @@ link_inverse.averaging <- function(x, ...) {
 }
 
 
+#' @export
+link_inverse.sdmTMB <- function(x, ...) {
+  f <- get_family(x)
+  stats::make.link(link = f$link)$linkinv
+}
+
+
 #' @export
 link_inverse.LORgee <- function(x, ...) {
   if (grepl(pattern = "logit", x = x$link, fixed = TRUE)) {
@@ -604,7 +627,8 @@ link_inverse.glmmTMB <- function(x, ...) {
 
 #' @export
 link_inverse.MCMCglmm <- function(x, ...) {
-  switch(x$Residual$original.family,
+  switch(
+    x$Residual$original.family,
     cengaussian = ,
     gaussian = stats::gaussian(link = "identity")$linkinv,
     categorical = ,
@@ -623,7 +647,8 @@ link_inverse.MCMCglmm <- function(x, ...) {
 
 #' @export
 link_inverse.glmm <- function(x, ...) {
-  switch(tolower(x$family.glmm$family.glmm),
+  switch(
+    tolower(x$family.glmm$family.glmm),
     bernoulli.glmm = ,
     binomial.glmm = stats::make.link("logit")$linkinv,
     poisson.glmm = stats::make.link("log")$linkinv,
@@ -649,7 +674,8 @@ link_inverse.stanmvreg <- function(x, ...) {
 
 #' @export
 link_inverse.gbm <- function(x, ...) {
-  switch(x$distribution$name,
+  switch(
+    x$distribution$name,
     laplace = ,
     tdist = ,
     gaussian = stats::gaussian(link = "identity")$linkinv,
@@ -692,7 +718,8 @@ link_inverse.gamlss <- function(x, what = c("mu", "sigma", "nu", "tau"), ...) {
   if (faminfo$family[1] == "LOGNO") {
     function(eta) pmax(exp(eta), .Machine$double.eps)
   } else {
-    switch(what,
+    switch(
+      what,
       mu = faminfo$mu.linkinv,
       sigma = faminfo$sigma.linkinv,
       nu = faminfo$nu.linkinv,
@@ -798,7 +825,9 @@ link_inverse.mira <- function(x, ...) {
 .get_cplm_family <- function(x) {
   link <- parse(text = safe_deparse(x@call))[[1]]$link
 
-  if (is.null(link)) link <- "log"
+  if (is.null(link)) {
+    link <- "log"
+  }
 
   if (is.numeric(link)) {
     check_if_installed("statmod")
